==> pyflowline-0.3.0-py2.py3-none-any.whl: pyflowline/formats/export_vertex.py <==
import os
from osgeo import ogr, osr
#from shapely.geometry import Point

def export_vertex_to_geojson(aVertex_in, 
        sFilename_json_in,
        iFlag_projected_in=None,
        pSpatial_reference_in=None, 
        aAttribute_data=None):
    """
    Convert a shapefile to json format.
    This function should be used for stream flowline only.

    Args:
        aVertex_in (_type_): _description_
        sFilename_json_in (_type_): _description_
        iFlag_projected_in (_type_, optional): _description_. Defaults to None.
        pSpatial_reference_in (_type_, optional): _description_. Defaults to None.
        aAttribute_data (_type_, optional): _description_. Defaults to None.
    """
    

    if os.path.exists(sFilename_json_in): 
        os.remove(sFilename_json_in)
        pass
    
    if iFlag_projected_in is None:
        iFlag_projected_in = 0
    else:
        iFlag_projected_in = 1

    if  pSpatial_reference_in is None:        
        pSpatial_reference_in = osr.SpatialReference()  
        pSpatial_reference_in.ImportFromEPSG(4326)    # WGS84 lat/lon
    else:
        pass

    if aAttribute_data is not None:
        aAttribute= aAttribute_data
        iFlag_attribute =1
    else:
        iFlag_attribute=0

    nVertex = len(aVertex_in)
    pDriver = ogr.GetDriverByName('GeoJSON')        
    pDataset_json = pDriver.CreateDataSource(sFilename_json_in)
    pLayer_json = pDataset_json.CreateLayer('vertex', pSpatial_reference_in, ogr.wkbPoint)
    # Add one attribute
    pLayer_json.CreateField(ogr.FieldDefn('pointid', ogr.OFTInteger64)) #long type for high resolution
    if iFlag_attribute ==1:        
        pLayer_json.CreateField(ogr.FieldDefn('connectivity', ogr.OFTInteger64)) #long type for high resolution
        pass

    pLayerDefn = pLayer_json.GetLayerDefn()
    pFeature_out = ogr.Feature(pLayerDefn)
    lID = 0
    for i in range(nVertex):       
        pVertex = aVertex_in[i]
        pPoint = ogr.Geometry(ogr.wkbPoint)
        if iFlag_projected_in ==1:
            #dummy1= Point( pVertex.dx, pVertex.dy )
            pPoint.AddPoint(pVertex.dx, pVertex.dy)
            pass
        else:
            #dummy1= Point( pVertex.dLongitude_degree, pVertex.dLatitude_degree ) 
            pPoint.AddPoint(pVertex.dLongitude_degree, pVertex.dLatitude_degree)
            pass


        pGeometry_out = ogr.CreateGeometryFromWkb(pPoint.ExportToWkb())
        pFeature_out.SetGeometry(pGeometry_out)   
        pFeature_out.SetField("pointid", lID)
        if iFlag_attribute ==1:
            pFeature_out.SetField("connectivity", int(aAttribute[i]) )
                
        pLayer_json.CreateFeature(pFeature_out)        
        lID =  lID + 1
        pass
        
    pDataset_json.FlushCache()
    pDataset_json = pLayer_json = pFeature_out  = None    

    return


def export_vertex_to_shapefile(aVertex_in, sFilename_shapefile_out,\
    pSpatial_reference_in, 
    iFlag_projected_in, 
    aAttribute_data=None):
    """
    convert a shpefile to json format.
    This function should be used for stream flowline only.
    """

    if os.path.exists(sFilename_shapefile_out): 
        os.remove(sFilename_shapefile_out)
        pass

    if aAttribute_data is not None:
        aAttribute= aAttribute_data
        iFlag_attribute =1
    else:
        iFlag_attribute=0

    nVertex = len(aVertex_in)
    pDriver = ogr.GetDriverByName('ESRI Shapefile')
    pDataset_json = pDriver.CreateDataSource(sFilename_shapefile_out)
    pLayer_json = pDataset_json.CreateLayer('vertex', pSpatial_reference_in, ogr.wkbPoint)
    # Add one attribute
    pLayer_json.CreateField(ogr.FieldDefn('id', ogr.OFTInteger64)) #long type for high resolution
    if iFlag_attribute ==1:        
        pLayer_json.CreateField(ogr.FieldDefn('con', ogr.OFTInteger64)) #long type for high resolution
        pass

    pLayerDefn = pLayer_json.GetLayerDefn()
    pFeature_out = ogr.Feature(pLayerDefn)
    lID = 0
    for i in range(nVertex):       
        pVertex = aVertex_in[i]
        pPoint = ogr.Geometry(ogr.wkbPoint)
        if iFlag_projected_in ==1:
            #dummy1= Point( pVertex.dx, pVertex.dy )             
            pPoint.AddPoint(pVertex.dx, pVertex.dy)
            pass
        else:
            #dummy1= Point( pVertex.dLongitude_degree, pVertex.dLatitude_degree ) 
            pPoint.AddPoint(pVertex.dLongitude_degree, pVertex.dLatitude_degree)
            pass

        #pGeometry_out = ogr.CreateGeometryFromWkb(dummy1.wkb)
        pGeometry_out = ogr.CreateGeometryFromWkb(pPoint.ExportToWkb())
        pFeature_out.SetGeometry(pGeometry_out)   
        pFeature_out.SetField("id", lID)
        if iFlag_attribute ==1:
            pFeature_out.SetField("con", int(aAttribute[i]) )
        
        # Add new pFeature_shapefile to output Layer
        pLayer_json.CreateFeature(pFeature_out)        
        lID =  lID + 1
        pass
        
    pDataset_json.FlushCache()
    pDataset_json = pLayer_json = pFeature_out  = None    

    return

==> pyflowline-0.3.10-py2.py3-none-any.whl: pyflowline/formats/export_vertex.py <==
import os
from osgeo import ogr, osr


def export_vertex_to_geojson(aVertex_in, 
        sFilename_json_in,
        iFlag_projected_in=None,
        pSpatial_reference_in=None, 
        aAttribute_data=None):
    """
    Convert a shapefile to json format.
    This function should be used for stream flowline only.

    Args:
        aVertex_in (_type_): _description_
        sFilename_json_in (_type_): _description_
        iFlag_projected_in (_type_, optional): _description_. Defaults to None.
        pSpatial_reference_in (_type_, optional): _description_. Defaults to None.
        aAttribute_data (_type_, optional): _description_. Defaults to None.
    """
    

    if os.path.exists(sFilename_json_in): 
        os.remove(sFilename_json_in)

    iFlag_projected_in = 0 if iFlag_projected_in is None else 1

    if  pSpatial_reference_in is None:        
        pSpatial_reference_in = osr.SpatialReference()  
        pSpatial_reference_in.ImportFromEPSG(4326)    # WGS84 lat/lon


    iFlag_attribute = 1 if aAttribute_data is not None else 0
    aAttribute = aAttribute_data if aAttribute_data is not None else []

    #nVertex = len(aVertex_in)
    pDriver = ogr.GetDriverByName('GeoJSON')        
    pDataset_json = pDriver.CreateDataSource(sFilename_json_in)
    pLayer_json = pDataset_json.CreateLayer('vertex', pSpatial_reference_in, ogr.wkbPoint)
    # Add one attribute
    pLayer_json.CreateField(ogr.FieldDefn('pointid', ogr.OFTInteger64)) #long type for high resolution
    if iFlag_attribute ==1:        
        pLayer_json.CreateField(ogr.FieldDefn('connectivity', ogr.OFTInteger64)) #long type for high resolution
        pass

    pLayerDefn = pLayer_json.GetLayerDefn()
    pFeature_out = ogr.Feature(pLayerDefn)
    #lID = 0
    #for i in range(nVertex):       
    #    pVertex = aVertex_in[i]
    #    pPoint = ogr.Geometry(ogr.wkbPoint)
    #    if iFlag_projected_in ==1:           
    #        pPoint.AddPoint(pVertex.dx, pVertex.dy)
    #        pass
    #    else:
    #        pPoint.AddPoint(pVertex.dLongitude_degree, pVertex.dLatitude_degree)
    #        pass
    #    pGeometry_out = ogr.CreateGeometryFromWkb(pPoint.ExportToWkb())
    #    pFeature_out.SetGeometry(pGeometry_out)   
    #    pFeature_out.SetField("pointid", lID)
    #    if iFlag_attribute ==1:
    #        pFeature_out.SetField("connectivity", int(aAttribute[i]) )
    #            
    #    pLayer_json.CreateFeature(pFeature_out)        
    #    lID =  lID + 1
    #    pass

    for lID, pVertex in enumerate(aVertex_in):
        pPoint = ogr.Geometry(ogr.wkbPoint)
        if iFlag_projected_in == 1:
            pPoint.AddPoint(pVertex.dx, pVertex.dy)
        else:
            pPoint.AddPoint(pVertex.dLongitude_degree, pVertex.dLatitude_degree)

        pGeometry_out = ogr.CreateGeometryFromWkb(pPoint.ExportToWkb())
        pFeature_out.SetGeometry(pGeometry_out)   
        pFeature_out.SetField("pointid", lID)

        if iFlag_attribute == 1:
            pFeature_out.SetField("connectivity", int(aAttribute[lID]))

        pLayer_json.CreateFeature(pFeature_out)    
        
    pDataset_json.FlushCache()
    pDataset_json = pLayer_json = pFeature_out  = None    

    return


def export_vertex_to_shapefile(aVertex_in, sFilename_shapefile_out,\
    pSpatial_reference_in, 
    iFlag_projected_in, 
    aAttribute_data=None):
    """
    convert a shpefile to json format.
    This function should be used for stream flowline only.
    """

    if os.path.exists(sFilename_shapefile_out): 
        os.remove(sFilename_shapefile_out)
        pass

    if aAttribute_data is not None:
        aAttribute= aAttribute_data
        iFlag_attribute =1
    else:
        iFlag_attribute=0

    nVertex = len(aVertex_in)
    pDriver = ogr.GetDriverByName('ESRI Shapefile')
    pDataset_json = pDriver.CreateDataSource(sFilename_shapefile_out)
    pLayer_json = pDataset_json.CreateLayer('vertex', pSpatial_reference_in, ogr.wkbPoint)
    # Add one attribute
    pLayer_json.CreateField(ogr.FieldDefn('id', ogr.OFTInteger64)) #long type for high resolution
    if iFlag_attribute ==1:        
        pLayer_json.CreateField(ogr.FieldDefn('con', ogr.OFTInteger64)) #long type for high resolution
        pass

    pLayerDefn = pLayer_json.GetLayerDefn()
    pFeature_out = ogr.Feature(pLayerDefn)
    lID = 0
    for i in range(nVertex):       
        pVertex = aVertex_in[i]
        pPoint = ogr.Geometry(ogr.wkbPoint)
        if iFlag_projected_in ==1:
            #dummy1= Point( pVertex.dx, pVertex.dy )             
            pPoint.AddPoint(pVertex.dx, pVertex.dy)
            pass
        else:
            #dummy1= Point( pVertex.dLongitude_degree, pVertex.dLatitude_degree ) 
            pPoint.AddPoint(pVertex.dLongitude_degree, pVertex.dLatitude_degree)
            pass

        #pGeometry_out = ogr.CreateGeometryFromWkb(dummy1.wkb)
        pGeometry_out = ogr.CreateGeometryFromWkb(pPoint.ExportToWkb())
        pFeature_out.SetGeometry(pGeometry_out)   
        pFeature_out.SetField("id", lID)
        if iFlag_attribute ==1:
            pFeature_out.SetField("con", int(aAttribute[i]) )
        
        # Add new pFeature_shapefile to output Layer
        pLayer_json.CreateFeature(pFeature_out)        
        lID =  lID + 1
        pass
        
    pDataset_json.FlushCache()
    pDataset_json = pLayer_json = pFeature_out  = None    

    return
